# pysaql
[![](https://img.shields.io/pypi/v/pysaql.svg)](https://pypi.org/pypi/pysaql/) [![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Python SAQL query builder

Features:

- <!-- list of features -->

Table of Contents:

- [Installation](#installation)
- [Guide](#guide)
- [Development](#development)

## Installation

pysaql requires Python 3.9 or above.

```bash
pip install pysaql
# or
poetry add pysaql
```

## Guide

<!-- Subsections explaining how to use the package -->

## Development

To develop pysaql, install dependencies and enable the pre-commit hook:

```bash
pip install pre-commit poetry
poetry install
pre-commit install -t pre-commit -t pre-push
```

To run tests:

```bash
poetry run pytest
```
